#!/bin/bash
set -e

#
# start the full YOUnite stack
#

echo creating the younite network...
docker network create younite 2> /dev/null || true

[ -z "$YOUNITE_HOSTNAME" ] && export YOUNITE_HOSTNAME=local.younite.org
echo YOUNITE_HOSTNAME defined as $YOUNITE_HOSTNAME

echo determining host IP address...
export HOST_IP=$(docker run --rm busybox sh -c "ping -c1 host.docker.internal | grep bytes.from | awk '{print \$4}' | sed s/:$//")
[ -z "$HOST_IP" ] && export HOST_IP=$(docker run --rm --network=younite --add-host=host.docker.internal:host-gateway busybox sh -c "ping -c1 host.docker.internal | grep bytes.from | awk '{print \$4}' | sed s/:$//")
if [ -z "$HOST_IP" ]; then
        echo "There is a Docker network connectivity issue. May I suggest troubleshooting with the Docker Busybox container."
        exit 1
fi
echo HOST_IP is $HOST_IP

echo downloading docker-compose files...
curl https://younite.us/attachments/docker-compose.yml --output docker-compose.yml

echo logging into ECR...
aws ecr get-login-password --region us-west-2 | docker login --username AWS --password-stdin 160909222919.dkr.ecr.us-west-2.amazonaws.com

./stop.sh

echo pulling latest images...
docker compose pull

echo starting up elasticsearch and keycloak...
docker compose up -d younite-elastic younite-keycloak

echo sleeping for 30 seconds ...
sleep 30

# wait for elastic to be "up" by checking its health endpoint
./wait-for-api.sh younite-elastic https://opensearch:admin@localhost:9200/_cluster/health status

# make sure the Open ID Connect configuration is accessible (Kibana needs this to configure itself)
./wait-for-api.sh younite-keycloak http://localhost:8800/auth/realms/younite/.well-known/openid-configuration younite

echo starting kibana and logstash...
docker compose up -d younite-kibana younite-logstash

echo sleeping for 60 seconds...
sleep 60

# wait for Kibana to be "green" (it actually reports a lot more information, but green is part of it)
./wait-for-api.sh younite-kibana http://localhost:5601/api/status green || exit 1

echo starting the rest of the stack...
docker compose up -d younite-db younite-mb younite-api younite-notification-service-db younite-notification-service younite-data-virtualization-service

echo sleeping for 60 seconds...
sleep 60

./wait-for-api.sh younite-api http://localhost:8080/health UP
./wait-for-api.sh younite-notification-service http://localhost:8082/actuator/health UP
./wait-for-api.sh younite-data-virtualization-service http://localhost:8084/actuator/health UP

./wait-for-ready.sh younite-api "Started listener for AR-Data"
./wait-for-ready.sh younite-notification-service "Started listener for Notification-Data"
./wait-for-ready.sh younite-data-virtualization-service "Started listener for AR-Assembly"

docker compose up -d younite-ui

echo "SUCCESS! The stack is ready to go."
