#!/bin/bash

#
# this script waits for a container to start by checking for a string at an API endpoint
# usage: ./wait-for-api.sh (container name) (health endpoint url) (string to check for)
#
# between attempts to check the health endpoint url, it will check to see
# if the docker container is running. if the container has stopped, it
# will output the log entries
#

container_name=$1
endpoint=$2
check_for=$3

noapi() {
  docker ps -a | grep -q "$container_name" || notstarted

  echo
  echo
  echo "ERROR - the $container_name container has stopped unexpectedly"
  echo
  echo "press a key to see the log entries, which may contain information"
  echo "as to why the service stopped. this information could help debug the problem."
  echo

  read -n 1 -s -r -p "Press any key to continue"

  echo

  docker logs "$container_name"

  exit 1
}

notstarted() {
  echo
  echo
  echo "ERROR - the $container_name container was not started, which should not have happened (problem with the docker-compose file?)"
  exit 1
}

docker ps | grep -q "$container_name" || noapi

while true; do

  echo
  echo "checking $container_name at $endpoint"
  if curl -k -m 10 -s "$endpoint" | grep -q "$check_for"; then
    break
  fi

  docker ps | grep -q "$container_name" || noapi

  echo "$container_name did not respond, sleeping for 30 seconds..."
  sleep 30
done

echo "SUCCESS! $container_name was started successfully!"
exit 0
