#!/bin/bash

#
# this script waits for a container to be "ready" by searching for
# text in the logs of the container
# usage: wait-for-ready.sh (container name) (text to find)
#
# between attempts to check the logs, it will check to see
# if the docker container is running. if the container has stopped, it
# will output the log entries.
#


container_name=$1
text_to_find=$2

noapi() {
  docker ps -a | grep -q "$container_name" || notstarted

  echo
  echo
  echo "ERROR - the $container_name container has stopped unexpectedly"
  echo
  echo "press a key to see the log entries, which may contain information"
  echo "as to why the service stopped. this information could help debug the problem."
  echo

  read -n 1 -s -r -p "Press any key to continue"

  echo

  docker logs "$container_name"

  exit 1
}

notstarted() {
  echo
  echo
  echo "ERROR - the $container_name container was not started, which should not have happened (problem with the docker-compose file?)"
  exit 1
}

docker ps | grep -q "$container_name" || noapi

while true; do

  echo
  echo "checking to see if $container_name is ready"
  if docker logs "$container_name" | grep -q "$text_to_find"; then
    break
  fi

  docker ps | grep -q "$container_name" || noapi

  echo "$container_name is not yet ready, sleeping for 30 seconds..."
  sleep 30
done

echo "SUCCESS! $container_name is ready!"
exit 0
